@@ -1,7 +1,7 @@
 package Aniki::Filter;
 use 5.014002;
 
-use namespace::autoclean;
+use namespace::sweep;
 use Mouse v2.4.5;
 
 has global_inflators => (
